--[[

Routines to handle the display of the remote map window.

]]

-- Function: Clears the POI location and other data.
local function EFM_MW_POIClear(POI)
	if(POI ~= nil) then
		POI:ClearAllPoints();
		POI.Location = nil;
		POI:Hide();
	end
end

-- Function: Clear old map node references.
local function EFM_MW_ClearPoints()
	--local myDebug = true;
	local index;

	-- Clear flight node points.
	index = 1;
	while (index < 50) do
--		EFM_Shared_DebugMessage("Clearing Map Window Node Point "..index, myDebug);

		POI = getglobal("EFM_MW_Node"..index);
		EFM_MW_POIClear(POI);
		index = index + 1;
	end

	-- Clear flight route lines.
	index = 1;
	while (getglobal("EFM_MW_Route"..index) ~= nil) do
--		EFM_Shared_DebugMessage("Clearing Map Window Node Lines "..index, myDebug);

		POI = getglobal("EFM_MW_Route"..index);
		EFM_MW_POIClear(POI);
		index = index + 1;
	end
end

-- Function: Display the flight map details.
local function EFM_MW_DisplayFlightMap(continentNum)
	--local myDebug = true;
	--EFM_Shared_DebugMessage("Displaying map for continent number "..continentNum, myDebug);

	local Texture_AltKnown = "Interface\\TaxiFrame\\UI-Taxi-Icon-Gray";
	local Texture_CurKnown = "Interface\\TaxiFrame\\UI-Taxi-Icon-Yellow";

	local numLines		= 0;
	local displayNode	= true;
	local routepoi		= 0;
	local numNodes		= 0;

	-- Set variables that get used a lot...
	local w		= 316;
	local h		= 352;

	-- Clear the seenRoutes variable.
	seenRoutes = {};

	-- Add all distant taxi buttons.
	EFM_TaxiDistantButtonData = {};

	local nodeList = EFM_NI_GetNode_List(continentNum);
	if (nodeList == nil) then
		return;
	end
	--EFM_Shared_DebugMessage("nodeList ~= nil", myDebug);

	for key, zone in pairs(nodeList) do
		numNodes	= numNodes + 1;
		displayNode	= true;  -- Default to not displaying the flight node.
		myNode		= EFM_NI_GetNodeByName(zone);

		--EFM_Shared_DebugMessage("node = "..zone, myDebug);

		if (myNode ~= nil)then
			if (myNode["fmLoc"] ~= nil) then
				--[[
				-- Hack to stop display of flight nodes from other faction for people with DK's
				if (myNode["zmLoc"] == nil) then
					displayNode = false;
				end
				]]

				if (string.find(zone, "Nighthaven, Moonglade") ~= nil) then
					-- Are we allowed to show the druid flight paths
					if (EFM_MyConf.DruidPaths == false) then
						numNodes = numNodes - 1;
						displayNode = false;
					end
				end

				-- If the node is not already drawn, and we are allowed to display it, then draw it...
				if (displayNode)then
					-- Set the texture for the flight path
					local myTexture = Texture_AltKnown;
					if (EFM_KP_CheckPaths(continentNum, zone)) then
						myTexture = Texture_CurKnown;
					end

					-- Create a button for the flight node if needed
					button = getglobal("EFM_MW_Node"..numNodes);
					if (button == nil) then
						button = CreateFrame("Button", "EFM_MW_Node"..numNodes, EFM_MapWindow_Map, "EFM_POI_Template");
					end
					button:SetID(numNodes);
					button.Location		= zone;
					button.Continent	= continentNum;

					-- Save the data for this button along with the zone name.
					EFM_TaxiDistantButtonData[numNodes] = {};
					EFM_SF_mergeTable(myNode, EFM_TaxiDistantButtonData[numNodes]);

					-- Get the x and y co-ords for the node.
					sX = w * tonumber(myNode["fmLoc"]["x"]);
					sY = h * tonumber(myNode["fmLoc"]["y"]);

					-- Display it.
					button:ClearAllPoints();
					button:SetPoint("CENTER", "EFM_MapWindow_Map", "BOTTOMLEFT", sX, sY);
					button:SetNormalTexture(myTexture);
					--button:SetFrameStrata("TOOLTIP");
					--button:SetFrameLevel(100);
					button:Show();

					-- Draw Routes on map
					if (myNode.routes ~= nil) then
						local flightDuration = "";

						table.sort(myNode.routes);

						for key, routeName in pairs(myNode.routes) do
--							if (not EFM_SF_StringInTable(seenRoutes, routeName)) then
								routepoi		= routepoi + 1;
								local endNode	= EFM_NI_GetNodeByName(routeName);
								if (endNode["fmLoc"] ~= nil) then
									-- Create a new texture for the route line if needed
									line = getglobal("EFM_MW_Route"..routepoi);
									if (line == nil) then
										line = EFM_MapWindow_Map:CreateTexture("EFM_MW_Route"..routepoi, "OVERLAY");
									end
									line:SetTexture("Interface\\TaxiFrame\\UI-Taxi-Line");

									if (line) then
										dX = w * tonumber(endNode["fmLoc"]["x"]);
										dY = h * tonumber(endNode["fmLoc"]["y"]);
										DrawRouteLine(line, "EFM_MapWindow_Map", sX, sY, dX, dY, 32);
										line:Show();
									end
								end
--							end
						end
						table.insert(seenRoutes, zone);
					end
				end
			end
		end
	end
end

-- Function: Initialization routine for the new map window
function EFM_MW_Init()
	-- Set button text to the correct versions
	local continentNames = { GetMapContinents() } ;
	for index = 1, 4 do
		local myText	= continentNames[index];
		local myButton	= getglobal("EFM_MapWindow_Con"..index);
        myButton:SetText(myText);
		
		local myButtonText = getglobal("EFM_MapWindow_Con"..index.."Text");
		myButtonText:SetFont(GameFontNormal:GetFont(), 10);
	end

	local myButtonText	= getglobal("EFM_MapWindow_QuitText");
	myButtonText:SetFont(GameFontNormal:GetFont(), 12);

	local myButtonText	= getglobal("EFM_MapWindow_ConfigText");
	myButtonText:SetFont(GameFontNormal:GetFont(), 12);
end

-- Function: Change to the new map display.
function EFM_MW_ChangeMap(newMap)
	local continentMap;

	if (newMap == 2) then
		continentMap	= "Interface\\TaxiFrame\\TAXIMAP0";
	elseif (newMap == 3) then
		continentMap	= "Interface\\TaxiFrame\\TAXIMAP530";
	elseif (newMap == 4) then
		continentMap	= "Interface\\TaxiFrame\\TAXIMAP571";
	else
		continentMap	= "Interface\\TaxiFrame\\TAXIMAP1";
		newMap		= 1;
	end

	for index = 1, 4 do
		local myButton = getglobal("EFM_MapWindow_Con"..index.."Text");
		if (index == newMap) then
			myButton:SetTextColor(1.0, 1.0, 0.0);
		else
			myButton:SetTextColor(0.5, 0.5, 0.5);
		end
	end

	EFM_MapWindow_MapTexture:SetTexture(continentMap);

	EFM_MW_ClearPoints();
	EFM_MW_DisplayFlightMap(newMap);
end

-- Function: Routine to handle opening the map screen.
function EFM_MW_OpenMap(mapNum)
	if (EFM_MapWindow:IsVisible()) then
		EFM_MapWindow:Hide();
		return;
	end

	if (mapNum == nil) then
		mapNum = GetCurrentMapContinent();
	end

	if ((mapNum < 1) or (mapNum > 3)) then
		mapNum = GetCurrentMapContinent();
	end

	EFM_MW_ChangeMap(mapNum);
	EFM_MapWindow:Show();
end
